import { Injectable } from "@angular/core";
import { HttpClient } from "@angular/common/http";
import { Observable } from "rxjs";
import { CapabilityRequest } from "../model/capability-request";
import { CapabilityExecution } from "../model/capability-execution";
import { JsonObject } from "@angular/compiler-cli/ngcc/src/packages/entry_point";

@Injectable({
  providedIn: "root",
})
export class CapabilityLauncherService {
  private endpoint = "capability/";

  constructor(private httpClient: HttpClient) {}

  /**
   * Create capability request and send it to capability service
   * @param: capabilityName  Name of capability to create request for
   * @param: parameters  Parameters for capability request
   */
  createRequest(capabilityName: string, parameters: JsonObject): Observable<CapabilityRequest> {
    const url = this.endpoint + capabilityName + "/request/create";
    return this.httpClient.post<CapabilityRequest>(url, JSON.stringify({ parameters: parameters }));
  }

  /**
   * Create standard CMS imaging request from previously exeuted calibration request and send it to capability service
   * @param: capabilityName  Name of capability to create request for
   * @param: requestId Id of calibration request to image
   */
  createImageRequestFromPreviousCal(
    followonType: string,
    requestId: string,
  ): Observable<CapabilityRequest> {
    const url = this.endpoint + "request/" + requestId + "/followon/" + followonType;
    return this.httpClient.post<CapabilityRequest>(url, null);
  }

  /**
   * Submit capability request
   * @param: requestId  ID of capability request to submit
   */
  submit(requestId: string): Observable<CapabilityExecution> {
    const url = `${this.endpoint}request/${requestId}/submit`;
    return this.httpClient.post<CapabilityExecution>(url, null);
  }
}
